@@ -1,9 +1,13 @@
 import unittest
 
 from Test.PySenseDashboardTests import PySenseDashboardTests
+from Test.PySenseElasticubeTests import PySenseElasticubeTests
+from Test.PySenseGroupTests import PySenseGroupTests
 from Test.PySenseTests import PySenseTests
 
 scale_test_suite = unittest.TestSuite([
+    unittest.TestLoader().loadTestsFromTestCase(PySenseGroupTests ),
+    unittest.TestLoader().loadTestsFromTestCase(PySenseElasticubeTests),
     unittest.TestLoader().loadTestsFromTestCase(PySenseDashboardTests),
     unittest.TestLoader().loadTestsFromTestCase(PySenseTests)
 ])
